# Development scripts

- `check`: Format, lint, and type check with ruff and mypy; Use `--dry` option for dry run
- `develop`: Spin up a local mosquitto broker via Docker
- `docs`: Build the documentation; Use `--reload` option to serve locally with live reload
- `setup`: Install or update the dependencies after a `git clone` or `git pull`; Also (re-)installs the local version of aiomqtt
- `test`: Run the tests

Styled after GitHub's ["Scripts to Rule Them All"](https://github.com/github/scripts-to-rule-them-all).
